@@ -74,6 +74,11 @@
 /*	IBM T.J. Watson Research
 /*	P.O. Box 704
 /*	Yorktown Heights, NY 10598, USA
+/*
+/*	Wietse Venema
+/*	Google, Inc.
+/*	111 8th Avenue
+/*	New York, NY 10011, USA
 /*--*/
 
 /* System library. */
@@ -216,6 +221,8 @@ WATCHDOG *watchdog_create(unsigned timeout, WATCHDOG_FN action, char *context)
 	    msg_fatal("%s: pipe: %m", myname);
 	non_blocking(watchdog_pipe[0], NON_BLOCKING);
 	non_blocking(watchdog_pipe[1], NON_BLOCKING);
+	close_on_exec(watchdog_pipe[0], CLOSE_ON_EXEC);	/* Fix 20190126 */
+	close_on_exec(watchdog_pipe[1], CLOSE_ON_EXEC);	/* Fix 20190126 */
 	event_enable_read(watchdog_pipe[0], watchdog_read, (void *) 0);
     }
 #endif
